@@ -13,7 +13,7 @@ ESTRUC_ *negate(ESTRUC_ *e)                  /* expression so far */
     }
 
     if (e->type & e_const)                  /* immediate value */
-        (int)e->evalue = -(int)e->evalue;
+        e->evalue = -(int)e->evalue;
     else
     {
         etoc(e);                            /* convert to code */
