@@ -4,7 +4,7 @@
 
 #include "iccomp.h"
 
-static unsigned
+static size_t
     size = 1;
 
 void push_dead()                            /* dead_sp: lastused, dead[0] = 0 */
