@@ -11,7 +11,7 @@ ESTRUC_ *stackframe(E_TYPE_ type)
 {
     frame.type = type;
 
-    switch (type)
+    switch ((int)type)
     {
         case e_int | e_const:
             frame.evalue = atoi(lexstring);
