@@ -9,7 +9,7 @@ char           *argtail;
 char           *cmdhead;
 char           *cmdtail;
 
-void (*builtinfun[]) ARG ((void)) =
+void (*builtinfun[])(void) =
      {
          fun_arg_head,
          fun_arg_tail,
@@ -46,17 +46,17 @@ void (*builtinfun[]) ARG ((void)) =
          fun_sizeoflist,
          fun_stat,
          fun_str_el,
-         fun_empty,                      /* strlwr */
-         fun_empty,                      /* strupr */
+         fun_strlwr,
+         fun_strupr,
          fun_system,
          
-         fun_empty,          /* strlen */
-         fun_empty,          /* substr */
+         fun_strlen,
+         fun_strfind,
          fun_getpid,
     
-         fun_empty,
-         fun_empty,
-         fun_empty,
+         fun_substr,
+         fun_getenv,
+         fun_backtick,
          fun_empty,
          fun_empty,
          fun_empty,
