@@ -27,15 +27,12 @@
     }
 */
 
-#ifdef MSDOS
-#pragma comment (lib, "icmexec")
-#pragma comment (lib, "../rss/icrss")
-#endif
-
 #include "icm-exec.h"
+#include "var/var.h"
 
 int main (int argc, char **argv)
 {
+    int idx;
     register char *progname;
 
     atexit (cleanup);
@@ -45,7 +42,7 @@ int main (int argc, char **argv)
 
     if (argc == 1)
     {
-        copyright("ICMAKE Binary Makefile Executor", version, release, 1);
+        copyright("ICMAKE Binary Makefile Executor", version, release);
         progname = program_name(argv[0]);
         printf ("This program is run as a child process of icmake.\n"
                 "Usage: %s [-t] bimfile\n"
@@ -67,16 +64,24 @@ int main (int argc, char **argv)
     if (!(infile = fopen (argv [1], READBINARY)))
         error("cannot open bimfile '%s' to read", argv[1]);
 
-    headerp = readheader(infile, version [0]);
+    headerp = readheader(infile, (size_t)version[0]);
 
                                         /* return array of global vars */
     if ((INT16)(nvar = getvar(infile, headerp, &var)) == -1)
         error("invalid macro file, cannot read variable section");
 
+        /* global strings haven't been initialized by the compiler yet, */
+        /* so that's icm-exec's job                                     */
+    for (idx = 0; idx < nvar; ++idx)
+    {
+        if (typeValue(var + idx) == e_str)
+            var[idx] = *stringConstructor();
+    }
+
     fseek(infile, headerp->offset[3], SEEK_SET);
 
     {
-        LISTVAR_ env = listConstructor();
+        LISTVAR_ env = *listConstructor();
 
         environ2list(&env);
         push(&env);             /* envp: 3rd arg of main() */
@@ -84,14 +89,13 @@ int main (int argc, char **argv)
     }
 
     {
-        LISTVAR_ args = listConstructor_s_cPP(argc, argv);
+        LISTVAR_ args = *listConstructor_s_cPP((size_t)argc, argv);
         push(&args);            /* argv: 2nd arg of main() */
         listDestructor(&args);
     }
 
-
     {
-        INTVAR_ nArgs = intConstructor_i(argc - 1);
+        INTVAR_ nArgs = *intConstructor_i(argc - 1);
         push(&nArgs);           /* argc: 1st arg of main() */
     }
 
@@ -103,3 +107,6 @@ int main (int argc, char **argv)
 
 
 
+
+
+
