@@ -1,13 +1,13 @@
 #include "list.ih"
 
-LISTVAR_ listConstructor_s_cPP(size_t argc, char **argv)
+LISTVAR_ *listConstructor_s_cPP(size_t argc, char **argv)
 {
-    LISTVAR_ ret = {e_list};
+    static LISTVAR_ ret = {e_list, {0}};
 
     ret.vu.i = newlist();
 
     for (; argc--; )
         listAdd_cP(&ret, *++argv);
     
-    return ret;
+    return &ret;
 }
