@@ -8,7 +8,7 @@ void listSub(LISTVAR_ *dest, LISTVAR_ const *rhs)
 
     if (nRhs)                      /* something to add   */
     {
-        LISTVAR_ copy = listCopyCons(dest);
+        LISTVAR_ copy = *listCopyCons(dest);
 
         for (idx = 0; idx < nRhs; ++idx)
         {
