@@ -19,7 +19,7 @@
 
 void fun_push_1_jmp_end ()
 {
-    INTVAR_ tmp = intConstructor_i(1);
+    INTVAR_ tmp = *intConstructor_i(1);
     push(&tmp);
     intDestructor(&tmp);
 
