@@ -3,7 +3,7 @@
 #include "../int/int.h"
 #include "../string/string.h"
 
-static  unsigned stackSize;
+static  size_t stackSize;
 
 VAR_   *stack;
 
@@ -11,12 +11,12 @@ size_t  sp;
 size_t  bp;
 
 
-void push(VAR_ const *var)
+void push(VAR_ const *varEl)
 {
     if (sp >= stackSize)
     {
         stackSize += 50;
         stack = xrealloc(stack, stackSize * sizeof(VAR_));
     }
-    stack[sp++] = copyCons(var);
+    stack[sp++] = *copyCons(varEl);
 }
