@@ -1,6 +1,6 @@
 #include "string.ih"
 
-char const *stringStr(STRINGVAR_ const *lhs)
+char *stringStr(STRINGVAR_ const *lhs)
 {
     return  str(lhs);
 }
