@@ -12,15 +12,6 @@ char
 char *temporary;
 char *source_name;
 char *dest_name;
-
-FILE
-    *fdest;
-
-FLAGS_
-    flags;
-
-int
-    errors;
-
-unsigned
-    redirect_nr = (unsigned)~0;
+FILE *fdest;
+FLAGS_ flags;
+int errors;
